summaryrefslogtreecommitdiff
path: root/subplot.py
diff options
context:
space:
mode:
Diffstat (limited to 'subplot.py')
-rw-r--r--subplot.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/subplot.py b/subplot.py
index 975b579..40678c2 100644
--- a/subplot.py
+++ b/subplot.py
@@ -4,7 +4,7 @@ import shutil
import tempfile
# A shell script to run the sp-codegen binary from the source directory's Rust
# build target directory, adding the -t option to use the source directory's
# template directory.
#
@@ -12,7 +12,7 @@ import tempfile
wrapper = """\
#!/bin/sh
set -eu
-exec '{srcdir}/target/debug/{prog}' "$@" --resources '{srcdir}/share'
+exec '{srcdir}/target/debug/{prog}' --resources '{srcdir}/share' "$@"
"""
@@ -33,7 +33,7 @@ def install_subplot(ctx):
# Create a "bin" directory for the wrapper. Can't put this into datadir, as
# some of Subplot's scenarios make assumptions on what files exist there.
bindir = ctx["bin-dir"] = tempfile.mkdtemp()
- for prog in ["sp-codegen", "sp-docgen"]:
+ for prog in ["subplot"]:
filename = os.path.join(bindir, prog)
with open(filename, "w") as f:
f.write(wrapper.format(prog=prog, srcdir=srcdir))
@@ -4,7 +4,7 @@ import shutil
import tempfile
-# A shell script to run the sp-codegen binary from the source directory's Rust
+# A shell script to run the subplot binary from the source directory's Rust
# build target directory, adding the -t option to use the source directory's
# template directory.